# ELIT

The Emory Language and Information Toolkit (ELIT) provides the state-of-the-art NLP models for the following tasks:

* [Tokenization](docs/tokenization.md)
* [Part-of-Speech Tagging](docs/part_of_speech_tagging.md)
* Named Entity Recognition
* Constituency Parsing
* Dependency Parsing
* Semantic Role Labeling
* AMR Parsing
* Coreference Resolution
* Emotion Detection

This is an open-source project led by the [Emory NLP](http://nlp.cs.emory.edu/) Research Laboratory and released under the [Apache License 2.0](LICENSE).

* The latest release: [2.0]()
* Contact: [Jinho D. Choi](http://www.cs.emory.edu/~choi)

## Resources

* [Getting Started](docs/getting_started.md)
* [Data Format](docs/data_format.md)
